@@ -4,9 +4,11 @@
 
 import 'chrome://actor-overlay/app.js';
 
+import type {ActorOverlayPageRemote} from 'chrome://actor-overlay/actor_overlay.mojom-webui.js';
 import type {ActorOverlayAppElement} from 'chrome://actor-overlay/app.js';
 import {ActorOverlayBrowserProxy} from 'chrome://actor-overlay/browser_proxy.js';
 import {assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
+import {microtasksFinished} from 'chrome://webui-test/test_util.js';
 
 import type {TestActorOverlayPageHandler} from './test_browser_proxy.js';
 import {TestActorOverlayBrowserProxy} from './test_browser_proxy.js';
@@ -14,17 +16,26 @@ import {TestActorOverlayBrowserProxy} from './test_browser_proxy.js';
 suite('Scrim', function() {
   let page: ActorOverlayAppElement;
   let testHandler: TestActorOverlayPageHandler;
+  let testRemote: ActorOverlayPageRemote;
 
-  setup(function() {
+  suiteSetup(function() {
     const testBrowserProxy = new TestActorOverlayBrowserProxy();
     ActorOverlayBrowserProxy.setInstance(testBrowserProxy);
     testHandler = testBrowserProxy.handler;
+    testRemote = testBrowserProxy.remote;
+  });
 
+  setup(function() {
+    testHandler.reset();
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     page = document.createElement('actor-overlay-app');
     document.body.appendChild(page);
   });
 
+  teardown(function() {
+    page.remove();
+  });
+
   test('PointerEnterAndLeave', async function() {
     page.dispatchEvent(new PointerEvent('pointerenter'));
     assertTrue(await testHandler.whenCalled('onHoverStatusChanged'));
@@ -32,4 +43,17 @@ suite('Scrim', function() {
     page.dispatchEvent(new PointerEvent('pointerleave'));
     assertFalse(await testHandler.whenCalled('onHoverStatusChanged'));
   });
+
+  test('SetScrimBackground', async function() {
+    // Initial state should not contain the background-visible class.
+    assertFalse(page.classList.contains('background-visible'));
+
+    testRemote.setScrimBackground(true);
+    await microtasksFinished();
+    assertTrue(page.classList.contains('background-visible'));
+
+    testRemote.setScrimBackground(false);
+    await microtasksFinished();
+    assertFalse(page.classList.contains('background-visible'));
+  });
 });
