@@ -169,7 +169,7 @@ suite('NewTabPageComposeboxTest', () => {
 
   async function uploadFileAndVerify(token: Object, file: File) {
     // Assert no files.
-    assertEquals(composeboxElement.$.carousel.files.length, 0);
+    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
 
     handler.setResultFor(ADD_FILE_CONTEXT_FN, Promise.resolve({token: token}));
 
@@ -240,7 +240,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Check submit button disabled and files empty.
     assertStyle(composeboxElement.$.submitIcon, 'cursor', 'default');
-    assertEquals(composeboxElement.$.carousel.files.length, 0);
+    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
 
     // Close composebox.
     const whenCloseComposebox =
@@ -258,6 +258,89 @@ suite('NewTabPageComposeboxTest', () => {
     assertStyle(composeboxElement.$.submitIcon, 'cursor', 'pointer');
   });
 
+  test('uploading/deleting pdf file queries zps', async () => {
+    loadTimeData.overrideValues({composeboxShowZps: true});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Autocomplete queried once when composebox is opened.
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
+    const id = generateZeroId();
+    await uploadFileAndVerify(
+        id, new File(['foo'], 'foo.pdf', {type: 'application/pdf'}));
+    callbackRouterRemote.onContextualInputStatusChanged(
+        id, FileUploadStatus.kProcessing, null);
+    await microtasksFinished();
+
+    // Autocomplete should be stopped (with matches cleared) and then
+    // queried again when a file is uploaded.
+    assertEquals(searchboxHandler.getCallCount('stopAutocomplete'), 1);
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 2);
+
+    // The suggest request should be triggered before the file has finished
+    // uploading.
+    callbackRouterRemote.onContextualInputStatusChanged(
+        id, FileUploadStatus.kUploadSuccessful, null);
+
+    // Delete the uploaded file.
+    const deletedId = composeboxElement.$.carousel.files[0]!.uuid;
+    composeboxElement.$.carousel.dispatchEvent(new CustomEvent('delete-file', {
+      detail: {
+        uuid: deletedId,
+      },
+      bubbles: true,
+      composed: true,
+    }));
+
+    await microtasksFinished();
+
+    // Deleting a file should also stop autocomplete (and clear matches) and
+    // then query autocomplete again for unimodal zps results.
+    assertEquals(searchboxHandler.getCallCount('stopAutocomplete'), 2);
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 3);
+  });
+
+  test('uploading image file without flag does nothing', async () => {
+    loadTimeData.overrideValues(
+        {composeboxShowZps: true, composeboxShowImageSuggestions: false});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Autocomplete queried once when composebox is opened.
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
+    const id = generateZeroId();
+    await uploadFileAndVerify(
+        id, new File(['foo'], 'foo.jpg', {type: 'image/jpeg'}));
+    callbackRouterRemote.onContextualInputStatusChanged(
+        id, FileUploadStatus.kProcessing, null);
+    await microtasksFinished();
+
+    // Autocomplete should not be queried again since the uploaded file is an
+    // image and the image suggest flag is disabled.
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
+  });
+
+  test('uploading image file with image suggest flag queries zps', async () => {
+    loadTimeData.overrideValues(
+        {composeboxShowZps: true, composeboxShowImageSuggest: true});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Autocomplete queried once when composebox is opened.
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
+    const id = generateZeroId();
+    await uploadFileAndVerify(
+        id, new File(['foo'], 'foo.jpg', {type: 'image/jpeg'}));
+    callbackRouterRemote.onContextualInputStatusChanged(
+        id, FileUploadStatus.kProcessing, null);
+    await microtasksFinished();
+
+    // Autocomplete should be stopped (with matches cleared) and then
+    // queried again when a file is uploaded.
+    assertEquals(searchboxHandler.getCallCount('stopAutocomplete'), 1);
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 2);
+  });
+
   [new File(['foo'], 'foo.jpg', {type: 'image/jpeg'}),
    new File(['foo'], 'foo.pdf', {type: 'application/pdf'})]
       .forEach((file) => {
@@ -319,8 +402,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Assert no files uploaded or rendered on the carousel
     assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 0);
-    const files = composeboxElement.$.carousel.files;
-    assertEquals(files.length, 0);
+    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
     assertEquals(
         1,
         metrics.count(
@@ -346,8 +428,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Assert no files uploaded or rendered on the carousel
     assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 0);
-    const files = composeboxElement.$.carousel.files;
-    assertEquals(files.length, 0);
+    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
     assertEquals(
         1,
         metrics.count(
@@ -381,8 +462,7 @@ suite('NewTabPageComposeboxTest', () => {
           await callbackRouterRemote.$.flushForTesting();
 
           // Assert no files in the carousel.
-          const files = composeboxElement.$.carousel.files;
-          assertEquals(files.length, 0);
+          assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
         });
   });
 
@@ -393,7 +473,7 @@ suite('NewTabPageComposeboxTest', () => {
         Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
 
     // Assert no files.
-    assertEquals(composeboxElement.$.carousel.files.length, 0);
+    assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
 
     // Arrange.
     const dataTransfer = new DataTransfer();
@@ -488,6 +568,10 @@ suite('NewTabPageComposeboxTest', () => {
   });
 
   test('image upload button clicks file input', async () => {
+    loadTimeData.overrideValues({
+      'composeboxShowContextMenu': false,
+    });
+    createComposeboxElement();
     const imageUploadEventPromise =
         eventToPromise('click', composeboxElement.$.imageInput);
     composeboxElement.$.imageUploadButton.click();
@@ -497,7 +581,11 @@ suite('NewTabPageComposeboxTest', () => {
   });
 
   test('file upload button clicks file input', async () => {
-    loadTimeData.overrideValues({'composeboxShowPdfUpload': true});
+    loadTimeData.overrideValues({
+      'composeboxShowPdfUpload': true,
+      'composeboxShowContextMenu': false,
+    });
+    createComposeboxElement();
     const fileUploadClickEventPromise =
         eventToPromise('click', composeboxElement.$.fileInput);
     composeboxElement.$.fileUploadButton.click();
@@ -702,28 +790,64 @@ suite('NewTabPageComposeboxTest', () => {
     // Add zps input.
     composeboxElement.$.input.value = '';
     composeboxElement.$.input.dispatchEvent(new Event('input'));
+    await microtasksFinished();
 
-    // Composebox dropdown should show in zps.
     const composeboxDropdown =
         composeboxElement.shadowRoot.querySelector<HTMLElement>('#matches');
     assertTrue(!!composeboxDropdown);
-    assertFalse(composeboxDropdown.hidden);
 
-    // Dropdown should not show for input with only spaces.
-    composeboxElement.$.input.value = ' ';
-    composeboxElement.$.input.dispatchEvent(new Event('input'));
-    await microtasksFinished();
+    // Composebox dropdown should not show for no matches.
     assertTrue(composeboxDropdown.hidden);
 
-    // Dropdown should show with text.
-    composeboxElement.$.input.value = ' hello';
+    const matches = [
+      createSearchMatch(),
+      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+    ];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          matches: matches,
+        }));
+    await microtasksFinished();
+
+    // Dropdown should show for when matches are available.
+    assertFalse(composeboxDropdown.hidden);
+  });
+
+  test('dropdown does not show when no typed suggestions enabled', async () => {
+    loadTimeData.overrideValues(
+        {composeboxShowZps: true, composeboxShowTypedSuggest: false});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Add zps input.
+    composeboxElement.$.input.value = '';
     composeboxElement.$.input.dispatchEvent(new Event('input'));
     await microtasksFinished();
+
+    const composeboxDropdown =
+        composeboxElement.shadowRoot.querySelector<HTMLElement>('#matches');
+    assertTrue(!!composeboxDropdown);
+
+    const matches = [
+      createSearchMatch(),
+      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+    ];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          matches: matches,
+        }));
+    await microtasksFinished();
+
+    // Dropdown should show for when matches are available.
     assertFalse(composeboxDropdown.hidden);
 
-    // Restore.
-    loadTimeData.overrideValues(
-        {composeboxShowZps: false, composeboxShowTypedSuggest: false});
+    composeboxElement.$.input.value = 'Hello';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+    await microtasksFinished();
+
+    // Dropdown should not show for typed input when typed suggest is
+    // disabled.
+    assertTrue(composeboxDropdown.hidden);
   });
 
   test('arrow up/down moves selection / focus', async () => {
@@ -756,16 +880,14 @@ suite('NewTabPageComposeboxTest', () => {
       composed: true,  // So it propagates across shadow DOM boundary.
       key: 'ArrowDown',
     });
+
     composeboxElement.$.input.dispatchEvent(arrowDownEvent);
     await microtasksFinished();
     assertTrue(arrowDownEvent.defaultPrevented);
 
-    // First match remains selected and does not get focus while focus is in the
-    // input.
+    // First match is selected
     assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
     assertEquals('hello world', composeboxElement.$.input.value);
-    assertEquals(
-        composeboxElement.$.input, composeboxElement.shadowRoot.activeElement);
 
     // Move the focus to the second match.
     matchEls[1]!.focus();
@@ -803,6 +925,109 @@ suite('NewTabPageComposeboxTest', () => {
     loadTimeData.overrideValues({composeboxShowZps: false});
   });
 
+  test('Selection is restored after selected match is removed', async () => {
+    loadTimeData.overrideValues(
+        {composeboxShowZps: true, composeboxShowTypedSuggest: true});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    composeboxElement.$.input.value = '';
+    composeboxElement.$.input.dispatchEvent(new InputEvent('input'));
+
+    let matches = [
+      createSearchMatch({
+        supportsDeletion: true,
+      }),
+    ];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input:
+              stringToMojoString16(composeboxElement.$.input.value.trimStart()),
+          matches,
+        }));
+    await microtasksFinished();
+    assertTrue(await areMatchesShowing());
+
+    let matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
+        'ntp-composebox-match');
+    assertEquals(1, matchEls.length);
+    // First match is not selected.
+    assertFalse(matchEls[0]!.hasAttribute(Attributes.SELECTED));
+
+    // Remove the first match.
+    matchEls[0]!.$.remove.click();
+    const args = await searchboxHandler.whenCalled('deleteAutocompleteMatch');
+    assertEquals(0, args[0]);
+    assertEquals(1, searchboxHandler.getCallCount('deleteAutocompleteMatch'));
+
+    searchboxHandler.reset();
+
+    matches = [
+      createSearchMatch({supportsDeletion: true}), createSearchMatch({
+        supportsDeletion: true,
+        fillIntoEdit: stringToMojoString16('hello world 2'),
+      }),
+    ];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16(''),
+          matches: matches,
+        }));
+    assertTrue(await areMatchesShowing());
+
+    matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
+        'ntp-composebox-match');
+    assertEquals(2, matchEls.length);
+
+    // First match is not selected.
+    assertFalse(matchEls[0]!.hasAttribute(Attributes.SELECTED));
+
+    const arrowDownEvent = new KeyboardEvent('keydown', {
+      bubbles: true,
+      cancelable: true,
+      composed: true,  // So it propagates across shadow DOM boundary.
+      key: 'ArrowDown',
+    });
+
+    composeboxElement.$.input.dispatchEvent(arrowDownEvent);
+    await microtasksFinished();
+    assertTrue(arrowDownEvent.defaultPrevented);
+
+    // First match is selected
+    assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
+    assertEquals('hello world', composeboxElement.$.input.value);
+
+    // By pressing 'Enter' on the button.
+    const keydownEvent = (new KeyboardEvent('keydown', {
+      bubbles: true,
+      cancelable: true,
+      composed: true,
+      key: 'Enter',
+    }));
+    assertTrue(!!matchEls[0]!.$.remove);
+    matchEls[0]!.$.remove.dispatchEvent(keydownEvent);
+    assertTrue(keydownEvent.defaultPrevented);
+    const keydownArgs =
+        await searchboxHandler.whenCalled('deleteAutocompleteMatch');
+    await microtasksFinished();
+    assertEquals(0, keydownArgs[0]);
+    assertEquals(1, searchboxHandler.getCallCount('deleteAutocompleteMatch'));
+
+    matches = [createSearchMatch({
+      supportsDeletion: true,
+      fillIntoEdit: stringToMojoString16('hello world 2'),
+    })];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16(''),
+          matches: matches,
+        }));
+    assertTrue(await areMatchesShowing());
+
+    assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
+    assertEquals('hello world 2', composeboxElement.$.input.value);
+  });
+
   test('smart compose response added', async () => {
     createComposeboxElement();
     await microtasksFinished();
@@ -822,6 +1047,36 @@ suite('NewTabPageComposeboxTest', () => {
     assertEquals('compose', composeboxElement.getSmartComposeForTesting());
   });
 
+  test('tab adds smart compose to input', async () => {
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Add input.
+    composeboxElement.$.input.value = 'smart ';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16('smart '),
+          matches: [],
+          smartComposeInlineHint: stringToMojoString16('compose'),
+        }));
+    await microtasksFinished();
+
+    const tabEvent = new KeyboardEvent('keydown', {
+      bubbles: true,
+      cancelable: true,
+      composed: true,  // So it propagates across shadow DOM boundary.
+      key: 'Tab',
+    });
+
+    composeboxElement.$.input.dispatchEvent(tabEvent);
+    await microtasksFinished();
+    assertTrue(tabEvent.defaultPrevented);
+
+    assertEquals('smart compose', composeboxElement.$.input.value);
+  });
+
   test('composebox does not open match when only file present', async () => {
     createComposeboxElement();
 
@@ -838,6 +1093,42 @@ suite('NewTabPageComposeboxTest', () => {
     assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 0);
   });
 
+  test('composebox does not show when image is present', async () => {
+    loadTimeData.overrideValues({
+      composeboxShowZps: true,
+      composeboxShowTypedSuggest: true,
+      composeboxShowImageSuggest: false,
+    });
+    createComposeboxElement();
+    // Autocomplete queried once when composebox is created.
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
+
+    const matches = [createSearchMatch()];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16(''),
+          matches,
+        }));
+    assertTrue(await areMatchesShowing());
+
+    // Upload an image.
+    const id = generateZeroId();
+    await uploadFileAndVerify(
+        id, new File(['foo'], 'foo.jpg', {type: 'image/jpeg'}));
+
+    callbackRouterRemote.onContextualInputStatusChanged(
+        id, FileUploadStatus.kUploadSuccessful, null);
+
+    // Matches should not show when image is present.
+    assertFalse(await areMatchesShowing());
+
+    // Do not query autocomplete with image present.
+    composeboxElement.$.input.value = 'T';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+    await microtasksFinished();
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
+  });
+
   test('delete button removes match', async () => {
     loadTimeData.overrideValues({composeboxShowZps: true});
     createComposeboxElement();
@@ -899,6 +1190,30 @@ suite('NewTabPageComposeboxTest', () => {
     assertEquals(0, handler.getCallCount('submitQuery'));
   });
 
+  test('composebox stops autocomplete when clearing input', async () => {
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Autocomplete should be queried when the composebox is created.
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 1);
+    assertEquals(searchboxHandler.getCallCount('stopAutocomplete'), 0);
+
+    // Autocomplete complete should be queried when input is typed.
+    composeboxElement.$.input.value = 'T';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+    await microtasksFinished();
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 2);
+
+    // Deleting to empty input should stop autocomplete before querying it
+    // again.
+    composeboxElement.$.input.value = '';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+    await microtasksFinished();
+
+    assertEquals(searchboxHandler.getCallCount('stopAutocomplete'), 1);
+    assertEquals(searchboxHandler.getCallCount('queryAutocomplete'), 3);
+  });
+
   suite('Context menu', () => {
     suiteSetup(() => {
       loadTimeData.overrideValues({
@@ -922,7 +1237,7 @@ suite('NewTabPageComposeboxTest', () => {
           Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
 
       // Assert no files.
-      assertEquals(composeboxElement.$.carousel.files.length, 0);
+      assertFalse(!!$$<HTMLElement>(composeboxElement, '#carousel'));
 
       const contextMenuButton = $$(composeboxElement, '#contextEntrypoint');
       assertTrue(!!contextMenuButton);
