@@ -8,7 +8,7 @@ import 'chrome://settings/settings.js';
 import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {CrInputElement, CrTextareaElement} from 'chrome://settings/lazy_load.js';
-import {AutofillManagerImpl, CountryDetailManagerProxyImpl} from 'chrome://settings/lazy_load.js';
+import {AutofillAddressOptInChange, AutofillManagerImpl, CountryDetailManagerProxyImpl} from 'chrome://settings/lazy_load.js';
 import {assertEquals, assertFalse, assertGT, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import type {MetricsTracker} from 'chrome://webui-test/metrics_test_support.js';
 import {fakeMetricsPrivate} from 'chrome://webui-test/metrics_test_support.js';
@@ -142,7 +142,7 @@ const ADDRESS_COMPONENTS_IL = {
 };
 
 suite('AutofillSectionUiTest', function() {
-  test('testAutofillExtensionIndicator', function() {
+  test('AutofillExtensionIndicator', function() {
     // Initializing with fake prefs
     const section = document.createElement('settings-autofill-section');
     section.prefs = {autofill: {profile_enabled: {}}};
@@ -164,9 +164,16 @@ suite('AutofillSectionUiTest', function() {
     const accountAddress = createAddressEntry();
     accountAddress.metadata!.recordType =
         chrome.autofillPrivate.AddressRecordType.ACCOUNT;
+    const homeAddress = createAddressEntry();
+    homeAddress.metadata!.recordType =
+        chrome.autofillPrivate.AddressRecordType.ACCOUNT_HOME;
+    const workAddress = createAddressEntry();
+    workAddress.metadata!.recordType =
+        chrome.autofillPrivate.AddressRecordType.ACCOUNT_WORK;
 
     const autofillManager = new TestAutofillManager();
-    autofillManager.data.addresses = [address, accountAddress];
+    autofillManager.data.addresses =
+        [address, accountAddress, homeAddress, workAddress];
     autofillManager.data.accountInfo = {
       ...STUB_USER_ACCOUNT_INFO,
       isSyncEnabledForAutofillProfiles: true,
@@ -181,15 +188,11 @@ suite('AutofillSectionUiTest', function() {
 
     {
       const dialog = await initiateRemoving(section, 0);
-      assertTrue(
-          !isVisible(dialog.$.accountAddressDescription),
-          'account notice should be invisible for non-account address');
-      assertTrue(
-          !isVisible(dialog.$.localAddressDescription),
-          'sync is enabled, an appropriate message should be visible');
-      assertTrue(
-          isVisible(dialog.$.syncAddressDescription),
-          'sync is enabled, an appropriate message should be visible');
+      const expectedMessage =
+          loadTimeData.getString('removeSyncAddressConfirmationDescription');
+      assertEquals(
+          dialog.$.description.textContent!.trim(), expectedMessage,
+          'Sync-on message should be visible');
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
       await eventToPromise('close', dialog.$.dialog);
@@ -210,15 +213,11 @@ suite('AutofillSectionUiTest', function() {
 
     {
       const dialog = await initiateRemoving(section, 0);
-      assertTrue(
-          !isVisible(dialog.$.accountAddressDescription),
-          'account notice should be invisible for non-account address');
-      assertTrue(
-          isVisible(dialog.$.localAddressDescription),
-          'sync is disabled, an appropriate message should be visible');
-      assertTrue(
-          !isVisible(dialog.$.syncAddressDescription),
-          'sync is disabled, an appropriate message should be visible');
+      const expectedMessage =
+          loadTimeData.getString('removeLocalAddressConfirmationDescription');
+      assertEquals(
+          dialog.$.description.textContent!.trim(), expectedMessage,
+          'Sync-off message should be visible');
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
       await eventToPromise('close', dialog.$.dialog);
@@ -231,15 +230,11 @@ suite('AutofillSectionUiTest', function() {
 
     {
       const dialog = await initiateRemoving(section, 0);
-      assertTrue(
-          !isVisible(dialog.$.accountAddressDescription),
-          'account notice should be invisible for non-account address');
-      assertTrue(
-          isVisible(dialog.$.localAddressDescription),
-          'sync is disabled, an appropriate message should be visible');
-      assertTrue(
-          !isVisible(dialog.$.syncAddressDescription),
-          'sync is disabled, an appropriate message should be visible');
+      const expectedMessage =
+          loadTimeData.getString('removeLocalAddressConfirmationDescription');
+      assertEquals(
+          dialog.$.description.textContent!.trim(), expectedMessage,
+          'Sync-off message should be visible when account info is missing');
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
       await eventToPromise('close', dialog.$.dialog);
@@ -254,15 +249,43 @@ suite('AutofillSectionUiTest', function() {
 
     {
       const dialog = await initiateRemoving(section, 1);
-      assertTrue(
-          isVisible(dialog.$.accountAddressDescription),
-          'account notice should be visible for non-account address');
-      assertTrue(
-          !isVisible(dialog.$.localAddressDescription),
-          'non-account messages should not be visible');
-      assertTrue(
-          !isVisible(dialog.$.syncAddressDescription),
-          'non-account messages should not be visible');
+      const expectedMessage = loadTimeData.getStringF(
+          'deleteAccountAddressRecordTypeNotice', STUB_USER_ACCOUNT_INFO.email);
+      assertEquals(
+          dialog.$.description.textContent!.trim(), expectedMessage,
+          'Account address message should be visible');
+      dialog.$.dialog.close();
+      // Make sure closing clean-ups are finished.
+      await eventToPromise('close', dialog.$.dialog);
+    }
+
+    await flushTasks();
+
+    {
+      const dialog = await initiateRemoving(section, 2);
+      const homeUrl = loadTimeData.getString('googleAccountHomeAddressUrl')
+                          .replace(/&/g, '&amp;');
+      const expectedMessage = loadTimeData.getStringF(
+          'deleteHomeAddressNotice', homeUrl, STUB_USER_ACCOUNT_INFO.email);
+      assertEquals(
+          dialog.$.description.innerHTML, expectedMessage,
+          `Home address delete confirmation view description is incorrect.`);
+      dialog.$.dialog.close();
+      // Make sure closing clean-ups are finished.
+      await eventToPromise('close', dialog.$.dialog);
+    }
+
+    await flushTasks();
+
+    {
+      const dialog = await initiateRemoving(section, 3);
+      const workUrl = loadTimeData.getString('googleAccountWorkAddressUrl')
+                          .replace(/&/g, '&amp;');
+      const expectedMessage = loadTimeData.getStringF(
+          'deleteWorkAddressNotice', workUrl, STUB_USER_ACCOUNT_INFO.email);
+      assertEquals(
+          dialog.$.description.innerHTML, expectedMessage,
+          `Work address delete confirmation view description is incorrect.`);
       dialog.$.dialog.close();
       // Make sure closing clean-ups are finished.
       await eventToPromise('close', dialog.$.dialog);
@@ -274,15 +297,13 @@ suite('AutofillSectionUiTest', function() {
   test('verifyAddressEditRecordTypeNotice', async () => {
     const email = 'stub-user@example.com';
     const address = createAddressEntry();
-    const accouontAddress = createAddressEntry();
-    accouontAddress.metadata!.recordType =
+    const accountAddress = createAddressEntry();
+    accountAddress.metadata!.recordType =
         chrome.autofillPrivate.AddressRecordType.ACCOUNT;
-    const section =
-        await createAutofillSection([address, accouontAddress], {}, {
-          ...STUB_USER_ACCOUNT_INFO,
-          email,
-        });
-    flush();
+    const section = await createAutofillSection([address, accountAddress], {}, {
+      ...STUB_USER_ACCOUNT_INFO,
+      email,
+    });
 
     {
       const dialog = await initiateEditing(section, 0);
@@ -334,6 +355,35 @@ suite('AutofillSectionAddressTests', function() {
     countryDetailManager.setGetAddressFormatRepsonse(ADDRESS_COMPONENTS_US);
   });
 
+  test('verifyAutofillAddressToggleMetric', async function() {
+    const section =
+        await createAutofillSection([], {profile_enabled: {value: true}});
+    const button = section.$.autofillProfileToggle;
+    assertTrue(!!button);
+
+    // The address profile toggle is on by default.
+    assertTrue(button.checked);
+    assertEquals(metricsTracker.count('Autofill.Address.IsEnabled.Change'), 0);
+
+    // Test that toggling the button off records the correct metric.
+    button.click();
+    assertEquals(metricsTracker.count('Autofill.Address.IsEnabled.Change'), 1);
+    assertEquals(
+        metricsTracker.count(
+            'Autofill.Address.IsEnabled.Change',
+            AutofillAddressOptInChange.OPT_OUT),
+        1);
+
+    // Test that toggling the button on records the correct metric.
+    button.click();
+    assertEquals(metricsTracker.count('Autofill.Address.IsEnabled.Change'), 2);
+    assertEquals(
+        metricsTracker.count(
+            'Autofill.Address.IsEnabled.Change',
+            AutofillAddressOptInChange.OPT_IN),
+        1);
+  });
+
   test('verifyNoAddresses', async function() {
     const section =
         await createAutofillSection([], {profile_enabled: {value: true}});
@@ -383,7 +433,6 @@ suite('AutofillSectionAddressTests', function() {
     const section = await createAutofillSection([address], {});
     const addressList = section.$.addressList;
     const row = addressList.children[0];
-    flush();
     assertTrue(!!row);
 
     const addressSummary =
@@ -400,46 +449,6 @@ suite('AutofillSectionAddressTests', function() {
     assertEquals(addressSummary, actualSummary);
   });
 
-  test('verifyAccountHomeAddress', async function() {
-    const openWindowProxy = new TestOpenWindowProxy();
-    OpenWindowProxyImpl.setInstance(openWindowProxy);
-    const homeAddress = createAddressEntry();
-    homeAddress.metadata!.recordType =
-        chrome.autofillPrivate.AddressRecordType.ACCOUNT_HOME;
-    const autofillSection = await createAutofillSection([homeAddress], {});
-    flush();
-
-    const homeAddressButton =
-        autofillSection.shadowRoot!.querySelector<CrLinkRowElement>(
-            '#homeAddress');
-    assertTrue(!!homeAddressButton);
-    // Validate that, when present, the button results in opening a URL.
-    homeAddressButton.click();
-    const url = await openWindowProxy.whenCalled('openUrl');
-    assertEquals(url, loadTimeData.getString('googleAccountHomeAddressUrl'));
-    autofillSection.remove();
-  });
-
-  test('verifyAccountWorkAddress', async function() {
-    const openWindowProxy = new TestOpenWindowProxy();
-    OpenWindowProxyImpl.setInstance(openWindowProxy);
-    const workAddress = createAddressEntry();
-    workAddress.metadata!.recordType =
-        chrome.autofillPrivate.AddressRecordType.ACCOUNT_WORK;
-    const autofillSection = await createAutofillSection([workAddress], {});
-    flush();
-
-    const workAddressButton =
-        autofillSection.shadowRoot!.querySelector<CrLinkRowElement>(
-            '#workAddress');
-    assertTrue(!!workAddressButton);
-    // Validate that, when present, the button results in opening a URL.
-    workAddressButton.click();
-    const url = await openWindowProxy.whenCalled('openUrl');
-    assertEquals(url, loadTimeData.getString('googleAccountWorkAddressUrl'));
-    autofillSection.remove();
-  });
-
   test('verifyAddressLocalIndication', async () => {
     const autofillManager = new TestAutofillManager();
     autofillManager.data.addresses = [createAddressEntry()];
@@ -452,31 +461,31 @@ suite('AutofillSectionAddressTests', function() {
     const section = document.createElement('settings-autofill-section');
     document.body.appendChild(section);
     await autofillManager.whenCalled('getAddressList');
-
     await flushTasks();
 
     const addressList = section.$.addressList;
+    const getIcon = () => addressList.children[0]!.querySelector<HTMLElement>(
+        '#address-row-icon');
 
+    const iconName1 = getIcon()!.getAttribute('icon');
     assertFalse(
-        isVisible(addressList.children[0]!.querySelector('[icon*=cloud-off]')),
+        !!iconName1 && iconName1.includes('cloud-off'),
         'Sync for addresses is enabled, the local indicator should be off.');
 
     const changeListener =
         autofillManager.lastCallback.setPersonalDataManagerListener!;
-
     changeListener(autofillManager.data.addresses, [], [], [], undefined);
+    const iconName2 = getIcon()!.getAttribute('icon');
     assertFalse(
-        isVisible(section.$.addressList.children[0]!.querySelector(
-            '[icon*=cloud-off]')),
+        !!iconName2 && iconName2.includes('cloud-off'),
         'The local indicator should not be shown to logged-out users');
 
     changeListener(
         autofillManager.data.addresses, [], [], [], STUB_USER_ACCOUNT_INFO);
     assertTrue(
-        isVisible(addressList.children[0]!.querySelector('[icon*=cloud-off]')),
+        isVisible(getIcon()),
         'Sync is disabled but the feature is on, the icon should be visible.');
 
-
     document.body.removeChild(section);
   });
 
@@ -484,7 +493,6 @@ suite('AutofillSectionAddressTests', function() {
     const address = createAddressEntry();
     const section = await createAutofillSection([address], {});
     const addressList = section.$.addressList;
-    flush();
     const row = addressList.children[0];
     assertTrue(!!row);
     const menuButton = row.querySelector<HTMLElement>('.address-menu');
@@ -495,6 +503,56 @@ suite('AutofillSectionAddressTests', function() {
     assertTrue(!!section.shadowRoot!.querySelector('#menuEditAddress'));
   });
 
+  test('verifyAccountHomeAddressEdit', async function() {
+    const openWindowProxy = new TestOpenWindowProxy();
+    OpenWindowProxyImpl.setInstance(openWindowProxy);
+    const homeAddress = createAddressEntry();
+    homeAddress.metadata!.recordType =
+        chrome.autofillPrivate.AddressRecordType.ACCOUNT_HOME;
+    const section = await createAutofillSection([homeAddress], {});
+
+    const addressList = section.$.addressList;
+    const row = addressList.children[0];
+    assertTrue(!!row);
+    const menuButton = row.querySelector<HTMLElement>('.address-menu');
+    assertTrue(!!menuButton);
+    menuButton.click();
+    flush();
+
+    const editButton =
+        section.shadowRoot!.querySelector<HTMLElement>('#menuEditAddress');
+    assertTrue(!!editButton);
+    editButton.click();
+
+    const url = await openWindowProxy.whenCalled('openUrl');
+    assertEquals(url, loadTimeData.getString('googleAccountHomeAddressUrl'));
+  });
+
+  test('verifyAccountWorkAddressEdit', async function() {
+    const openWindowProxy = new TestOpenWindowProxy();
+    OpenWindowProxyImpl.setInstance(openWindowProxy);
+    const workAddress = createAddressEntry();
+    workAddress.metadata!.recordType =
+        chrome.autofillPrivate.AddressRecordType.ACCOUNT_WORK;
+    const section = await createAutofillSection([workAddress], {});
+
+    const addressList = section.$.addressList;
+    const row = addressList.children[0];
+    assertTrue(!!row);
+    const menuButton = row.querySelector<HTMLElement>('.address-menu');
+    assertTrue(!!menuButton);
+    menuButton.click();
+    flush();
+
+    const editButton =
+        section.shadowRoot!.querySelector<HTMLElement>('#menuEditAddress');
+    assertTrue(!!editButton);
+    editButton.click();
+
+    const url = await openWindowProxy.whenCalled('openUrl');
+    assertEquals(url, loadTimeData.getString('googleAccountWorkAddressUrl'));
+  });
+
   test('verifyAddAddressDialog', function() {
     const address = createEmptyAddressEntry();
     return createAddressDialog(address).then(function(dialog) {
