@@ -689,6 +689,28 @@ suite('SyncControlsAccountSettingsTest', function() {
     assertSyncDisabledPolicyIndicatorShown(false);
     assertIndividualItemPolicyIndicatorsShown(true);
   });
+
+  // Before crbug.com/433895051, the toggles were not shown before a syncStatus
+  // update or refresh when the user navigated to the account settings page from
+  // a different settings page. This test verifies they are shown directly upon
+  // navigation.
+  test('TogglesVisibilityUpdatedUponNavigation', async () => {
+    const router = Router.getInstance();
+    router.navigateTo(routes.PEOPLE);
+
+    // Create the sync controls before navigating to the account settings page.
+    document.body.innerHTML = window.trustedTypes!.emptyHTML;
+    syncControls = document.createElement('settings-sync-controls');
+    document.body.appendChild(syncControls);
+    syncControls.syncStatus = {
+      signedInState: SignedInState.SIGNED_IN,
+      statusAction: StatusAction.NO_ACTION,
+    };
+    await waitAfterNextRender(syncControls);
+
+    router.navigateTo(routes.ACCOUNT);
+    assertFalse(syncControls.hidden);
+  });
 });
 // </if>
 
