@@ -7,8 +7,8 @@ import 'chrome://settings/lazy_load.js';
 
 import {flush} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import type {SettingsPersonalizationOptionsElement} from 'chrome://settings/lazy_load.js';
-import type {PrivacyPageVisibility, SettingsPrefsElement} from 'chrome://settings/settings.js';
-import {CrSettingsPrefs, loadTimeData, PrivacyPageBrowserProxyImpl, SignedInState, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
+import type {SettingsPrefsElement} from 'chrome://settings/settings.js';
+import {CrSettingsPrefs, loadTimeData, PrivacyPageBrowserProxyImpl, resetPageVisibilityForTesting, SignedInState, StatusAction, SyncBrowserProxyImpl} from 'chrome://settings/settings.js';
 import {assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import {isVisible} from 'chrome://webui-test/test_util.js';
 // <if expr="_google_chrome or not is_chromeos">
@@ -19,6 +19,7 @@ import {assertEquals} from 'chrome://webui-test/chai_assert.js';
 import {eventToPromise} from 'chrome://webui-test/test_util.js';
 import {ChromeSigninUserChoice} from 'chrome://settings/settings.js';
 import {webUIListenerCallback} from 'chrome://resources/js/cr.js';
+
 // </if>
 
 import {TestPrivacyPageBrowserProxy} from './test_privacy_page_browser_proxy.js';
@@ -41,14 +42,11 @@ suite('AllBuilds', function() {
     return CrSettingsPrefs.initialized;
   });
 
-  function buildTestElement(customPageVisibility?: PrivacyPageVisibility) {
+  function buildTestElement() {
     document.body.innerHTML = window.trustedTypes!.emptyHTML;
     testElement = document.createElement('settings-personalization-options');
     testElement.prefs = settingsPrefs.prefs!;
     testElement.set('prefs.page_content_collection.enabled.value', false);
-    if (customPageVisibility) {
-      testElement.pageVisibility = customPageVisibility;
-    }
     document.body.appendChild(testElement);
     flush();
   }
@@ -63,6 +61,7 @@ suite('AllBuilds', function() {
 
   teardown(function() {
     testElement.remove();
+    resetPageVisibilityForTesting();
   });
 
   // <if expr="not is_chromeos">
@@ -142,8 +141,6 @@ suite('AllBuilds', function() {
   test(
       'chromeSigninUserChoiceAvailabilityUpdateWithSnackbarEnabled',
       async function() {
-        loadTimeData.overrideValues({isSnackbarForSettingsEnabled: true});
-
         const infoResponse = {
           shouldShowSettings: true,
           choice: ChromeSigninUserChoice.ALWAYS_ASK,
@@ -166,35 +163,6 @@ suite('AllBuilds', function() {
         assertTrue(testElement.$.chromeSigninUserChoiceToast.open);
       });
 
-  test(
-      'chromeSigninUserChoiceAvailabilityUpdateWithSnackbarDisabled',
-      async function() {
-        loadTimeData.overrideValues({isSnackbarForSettingsEnabled: false});
-
-        const infoResponse = {
-          shouldShowSettings: true,
-          choice: ChromeSigninUserChoice.ALWAYS_ASK,
-          signedInEmail: 'test@gmail.com',
-        };
-        syncBrowserProxy.setGetUserChromeSigninUserChoiceInfoResponse(
-            infoResponse);
-
-        buildTestElement();  // Rebuild the element simulating a fresh start.
-        await syncBrowserProxy.whenCalled('getChromeSigninUserChoiceInfo');
-        assertTrue(isVisible(testElement.$.chromeSigninUserChoiceSelection));
-
-
-        // Update user selection
-        const menu = testElement.$.chromeSigninUserChoiceSelection;
-        menu.value = ChromeSigninUserChoice.SIGNIN.toString();
-        menu.dispatchEvent(new CustomEvent('change'));
-        flush();
-
-        assertTrue(isVisible(testElement.$.chromeSigninUserChoiceSelection));
-        assertFalse(testElement.$.chromeSigninUserChoiceToast.open);
-      });
-
-
   test('signinAllowedToggle', function() {
     const toggle = testElement.$.signinAllowedToggle;
     assertTrue(isVisible(toggle));
@@ -318,19 +286,25 @@ suite('AllBuilds', function() {
   });
 
   test('searchSuggestToggleHiddenByPageVisibility', function() {
-    buildTestElement({
-      searchPrediction: false,
-      networkPrediction: false,
+    resetPageVisibilityForTesting({
+      privacy: {
+        searchPrediction: false,
+        networkPrediction: false,
+      },
     });
+    buildTestElement();
     assertFalse(isVisible(
         testElement.shadowRoot!.querySelector('#searchSuggestToggle')));
   });
 
   test('searchSuggestToggleShownByPageVisibility', function() {
-    buildTestElement({
-      searchPrediction: true,
-      networkPrediction: false,
+    resetPageVisibilityForTesting({
+      privacy: {
+        searchPrediction: true,
+        networkPrediction: false,
+      },
     });
+    buildTestElement();
     assertTrue(isVisible(
         testElement.shadowRoot!.querySelector('#searchSuggestToggle')));
   });
