@@ -3,16 +3,18 @@
 // found in the LICENSE file.
 import 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 
-import {BrowserProxy, NodeStore, previousReadHighlightClass, ReadAloudHighlighter, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
+import {AxReadAloudNode, BrowserProxy, NodeStore, previousReadHighlightClass, ReadAloudHighlighter, setInstance, WordBoundaries} from 'chrome-untrusted://read-anything-side-panel.top-chrome/read_anything.js';
 import {assertEquals, assertFalse, assertStringContains, assertStringExcludes, assertTrue} from 'chrome-untrusted://webui-test/chai_assert.js';
 
 import {FakeReadingMode} from './fake_reading_mode.js';
 import {TestColorUpdaterBrowserProxy} from './test_color_updater_browser_proxy.js';
+import {TestReadAloudModelBrowserProxy} from './test_read_aloud_browser_proxy.js';
 
 suite('Highlighter', () => {
   let highlighter: ReadAloudHighlighter;
   let nodeStore: NodeStore;
   let wordBoundaries: WordBoundaries;
+  let readAloudModel: TestReadAloudModelBrowserProxy;
 
   function assertFullNodeIsHighlighted(id: number, text: string) {
     assertEquals(
@@ -22,7 +24,9 @@ suite('Highlighter', () => {
   }
 
   function assertHtml(html: string, id: number) {
-    assertEquals(html, (nodeStore.getDomNode(id) as Element).innerHTML);
+    assertEquals(
+        html, (nodeStore.getDomNode(id) as Element).innerHTML,
+        (nodeStore.getDomNode(id) as Element).innerHTML);
   }
 
   function assertHtmlContains(partialHtml: string, id: number) {
@@ -43,6 +47,8 @@ suite('Highlighter', () => {
     chrome.readingMode = readingMode as unknown as typeof chrome.readingMode;
     chrome.readingMode.isPhraseHighlightingEnabled = true;
 
+    readAloudModel = new TestReadAloudModelBrowserProxy();
+    setInstance(readAloudModel);
     highlighter = new ReadAloudHighlighter();
     nodeStore = NodeStore.getInstance();
     nodeStore.clear();
@@ -50,40 +56,33 @@ suite('Highlighter', () => {
     wordBoundaries.resetToDefaultState();
   });
 
-  test('isInvalidHighlightForWordHighlighting', () => {
-    assertTrue(highlighter.isInvalidHighlightForWordHighlighting());
-    assertTrue(highlighter.isInvalidHighlightForWordHighlighting(''));
-    assertTrue(highlighter.isInvalidHighlightForWordHighlighting(' '));
-    assertTrue(highlighter.isInvalidHighlightForWordHighlighting('  '));
-    assertTrue(highlighter.isInvalidHighlightForWordHighlighting('!'));
-    assertTrue(highlighter.isInvalidHighlightForWordHighlighting('()?!?'));
-    assertFalse(highlighter.isInvalidHighlightForWordHighlighting('hello !!!'));
-    assertFalse(highlighter.isInvalidHighlightForWordHighlighting('(psst);'));
-  });
-
   test('sentence highlight', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.sentenceHighlighting);
 
-    const id = 10;
+    const nodeId = 10;
     const sentence = document.createElement('p');
     const text1 = 'When my legs don\'t work like they used to before. ';
     const text2 = 'And I can\'t sweep you off of your feet.';
     sentence.appendChild(document.createTextNode(text1 + text2));
-    nodeStore.setDomNode(sentence, id);
-    chrome.readingMode.getCurrentTextStartIndex = () => text1.length;
-    chrome.readingMode.getCurrentTextEndIndex = () =>
-        text1.length + text2.length;
+    nodeStore.setDomNode(sentence, nodeId);
+    const segments = [{
+      node: new AxReadAloudNode(nodeId),
+      start: text1.length,
+      length: text2.length,
+    }];
+    readAloudModel.setCurrentTextSegments(segments);
 
     highlighter.highlightCurrentGranularity(
-        [id], /*scrollIntoView=*/ false,
+        segments,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
     assertTrue(highlighter.hasCurrentHighlights());
     assertHtml(
         '<span class="previous-read-highlight">' + text1 + '</span>' +
             '<span class="current-read-highlight">' + text2 + '</span>',
-        id);
+        nodeId);
   });
 
   test('sentence highlight across multiple nodes', () => {
@@ -99,12 +98,15 @@ suite('Highlighter', () => {
     const id2 = 12;
     nodeStore.setDomNode(sentence, id1);
     nodeStore.setDomNode(bold, id2);
-    chrome.readingMode.getCurrentTextStartIndex = () => 0;
-    chrome.readingMode.getCurrentTextEndIndex = () =>
-        text1.length + text2.length;
+    const segments = [
+      {node: new AxReadAloudNode(id1), start: 0, length: text1.length},
+      {node: new AxReadAloudNode(id2), start: 0, length: text2.length},
+    ];
+    readAloudModel.setCurrentTextSegments(segments);
 
     highlighter.highlightCurrentGranularity(
-        [id1, id2], /*scrollIntoView=*/ false,
+        segments,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
     assertTrue(highlighter.hasCurrentHighlights());
@@ -122,11 +124,13 @@ suite('Highlighter', () => {
     const text = 'Woke up today, feeling the way I always do. ';
     sentence.appendChild(document.createTextNode(text));
     nodeStore.setDomNode(sentence, id);
-    chrome.readingMode.getCurrentTextStartIndex = () => 0;
-    chrome.readingMode.getCurrentTextEndIndex = () => text.length;
+    const segments =
+        [{node: new AxReadAloudNode(id), start: 0, length: text.length}];
+    readAloudModel.setCurrentTextSegments(segments);
 
     highlighter.highlightCurrentGranularity(
-        [id], /*scrollIntoView=*/ false,
+        segments,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
     assertTrue(highlighter.hasCurrentHighlights());
@@ -138,15 +142,16 @@ suite('Highlighter', () => {
         chrome.readingMode.wordHighlighting);
     wordBoundaries.updateBoundary(0);
     const id = 10;
-    chrome.readingMode.getHighlightForCurrentSegmentIndex =
-        () => [{nodeId: id, start: 5, length: 5}];
+    const highlights = [{node: new AxReadAloudNode(id), start: 5, length: 5}];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
     const sentence = document.createElement('p');
     sentence.appendChild(document.createTextNode(
         'Will your your eyes still smile from your cheeks?'));
     nodeStore.setDomNode(sentence, id);
 
     highlighter.highlightCurrentGranularity(
-        [id], /*scrollIntoView=*/ false,
+        highlights,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
     assertTrue(highlighter.hasCurrentHighlights());
@@ -157,6 +162,37 @@ suite('Highlighter', () => {
         id);
   });
 
+  test(
+      'onWillMoveToNextGranularity with word highlighting highlights the rest of the sentence',
+      () => {
+        chrome.readingMode.onHighlightGranularityChanged(
+            chrome.readingMode.wordHighlighting);
+        wordBoundaries.updateBoundary(0);
+        const id = 10;
+        const highlights =
+            [{node: new AxReadAloudNode(id), start: 0, length: 3}];
+        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+        const sentence = document.createElement('p');
+        const text = 'Do you believe in life after love?';
+        sentence.appendChild(document.createTextNode(text));
+        nodeStore.setDomNode(sentence, id);
+        chrome.readingMode.getTextContent = () => text;
+        const segments =
+            [{node: new AxReadAloudNode(id), start: 0, length: text.length}];
+        readAloudModel.setCurrentTextSegments(segments);
+        highlighter.highlightCurrentGranularity(
+            segments,
+            /*scrollIntoView=*/ false,
+            /*shouldUpdateSentenceHighlight=*/ true);
+        highlighter.onWillMoveToNextGranularity(segments);
+
+        assertFalse(highlighter.hasCurrentHighlights());
+        assertHtml(
+            '<span class="previous-read-highlight">Do you believe in life ' +
+                'after love?</span>',
+            id);
+      });
+
   test('word highlight across multiple nodes with engine length', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.wordHighlighting);
@@ -172,17 +208,17 @@ suite('Highlighter', () => {
     sentence.appendChild(document.createTextNode(text2));
     const id1 = 10;
     const id2 = 12;
-    chrome.readingMode.getHighlightForCurrentSegmentIndex = () =>
-        [{nodeId: id1, start: 0, length: 3},
-         {nodeId: id2, start: 0, length: 1}];
+    const highlights = [
+      {node: new AxReadAloudNode(id1), start: 0, length: 3},
+      {node: new AxReadAloudNode(id2), start: 0, length: 1},
+    ];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
     nodeStore.setDomNode(bold, id1);
     nodeStore.setDomNode(sentence, id2);
-    chrome.readingMode.getCurrentTextStartIndex = () => 0;
-    chrome.readingMode.getCurrentTextEndIndex = () =>
-        text1.length + text2.length;
 
     highlighter.highlightCurrentGranularity(
-        [id1, id2], /*scrollIntoView=*/ false,
+        highlights,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
     assertTrue(highlighter.hasCurrentHighlights());
@@ -193,20 +229,55 @@ suite('Highlighter', () => {
     assertHtml(' slipping into the lava.', id2);
   });
 
+  test('word highlight on punctuation only applies previous highlight', () => {
+    chrome.readingMode.onHighlightGranularityChanged(
+        chrome.readingMode.wordHighlighting);
+    wordBoundaries.updateBoundary(0);
+    const id = 10;
+    const sentenceText = 'And I can\'t sweep you off of your feet';
+    const punctuation = '.';
+
+    // Mock the backend to return a segment for just the punctuation.
+    const highlights = [{
+      node: new AxReadAloudNode(id),
+      start: sentenceText.length,
+      length: 1,
+    }];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+
+    const sentence = document.createElement('p');
+    sentence.appendChild(document.createTextNode(sentenceText + punctuation));
+    nodeStore.setDomNode(sentence, id);
+
+    highlighter.highlightCurrentGranularity(
+        highlights,
+        /*scrollIntoView=*/ false,
+        /*shouldUpdateSentenceHighlight=*/ true);
+
+    // There should be no "current" highlight on the page.
+    assertFalse(highlighter.hasCurrentHighlights());
+    assertHtml(
+        '<span class="previous-read-highlight">' + sentenceText +
+            '</span><span class="previous-read-highlight">' + punctuation +
+            '</span>',
+        id);
+  });
+
   test('phrase highlight', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.autoHighlighting);
     wordBoundaries.updateBoundary(0);
     const id = 10;
-    chrome.readingMode.getHighlightForCurrentSegmentIndex =
-        () => [{nodeId: id, start: 12, length: 20}];
+    const highlights = [{node: new AxReadAloudNode(id), start: 12, length: 20}];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
     const sentence = document.createElement('p');
     sentence.appendChild(document.createTextNode(
         'But darling I will be loving you till we\'re 70.'));
     nodeStore.setDomNode(sentence, id);
 
     highlighter.highlightCurrentGranularity(
-        [id], /*scrollIntoView=*/ false,
+        highlights,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
     assertTrue(highlighter.hasCurrentHighlights());
@@ -217,6 +288,37 @@ suite('Highlighter', () => {
         id);
   });
 
+  test(
+      'onWillMoveToNextGranularity with phrase highlighting highlights the rest of the sentence',
+      () => {
+        chrome.readingMode.onHighlightGranularityChanged(
+            chrome.readingMode.autoHighlighting);
+        wordBoundaries.updateBoundary(0);
+        const id = 10;
+        const highlights =
+            [{node: new AxReadAloudNode(id), start: 0, length: 2}];
+        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
+        const sentence = document.createElement('p');
+        const text = 'I can feel something inside me say';
+        sentence.appendChild(document.createTextNode(text));
+        nodeStore.setDomNode(sentence, id);
+        chrome.readingMode.getTextContent = () => text;
+        const segments =
+            [{node: new AxReadAloudNode(id), start: 0, length: text.length}];
+        readAloudModel.setCurrentTextSegments(segments);
+        highlighter.highlightCurrentGranularity(
+            segments,
+            /*scrollIntoView=*/ false,
+            /*shouldUpdateSentenceHighlight=*/ true);
+        highlighter.onWillMoveToNextGranularity(segments);
+
+        assertFalse(highlighter.hasCurrentHighlights());
+        assertHtml(
+            '<span class="previous-read-highlight">I can feel something ' +
+                'inside me say</span>',
+            id);
+      });
+
   test('phrase highlight across multiple nodes', () => {
     chrome.readingMode.onHighlightGranularityChanged(
         chrome.readingMode.autoHighlighting);
@@ -232,12 +334,15 @@ suite('Highlighter', () => {
     bold.appendChild(document.createTextNode(text2));
     nodeStore.setDomNode(sentence, id1);
     nodeStore.setDomNode(bold, id2);
-    chrome.readingMode.getHighlightForCurrentSegmentIndex = () =>
-        [{nodeId: id1, start: 10, length: 9},
-         {nodeId: id2, start: 0, length: 23}];
+    const highlights = [
+      {node: new AxReadAloudNode(id1), start: 10, length: 9},
+      {node: new AxReadAloudNode(id2), start: 0, length: 23},
+    ];
+    readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
 
     highlighter.highlightCurrentGranularity(
-        [id1, id2], /*scrollIntoView=*/ false,
+        highlights,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
 
 
@@ -260,15 +365,17 @@ suite('Highlighter', () => {
         chrome.readingMode.onSpeechRateChange(1);
         wordBoundaries.updateBoundary(0);
         const id = 10;
-        chrome.readingMode.getHighlightForCurrentSegmentIndex =
-            () => [{nodeId: id, start: 0, length: 20}];
+        const highlights =
+            [{node: new AxReadAloudNode(id), start: 0, length: 20}];
+        readAloudModel.setHighlightForCurrentSegmentIndex(highlights);
         const sentence = document.createElement('p');
         sentence.appendChild(document.createTextNode(
             'Hungry for something that I can\'t eat. '));
         nodeStore.setDomNode(sentence, id);
 
         highlighter.highlightCurrentGranularity(
-            [id], /*scrollIntoView=*/ false,
+            [],
+            /*scrollIntoView=*/ false,
             /*shouldUpdateSentenceHighlight=*/ true);
 
         assertTrue(highlighter.hasCurrentHighlights());
@@ -288,14 +395,18 @@ suite('Highlighter', () => {
     const text2 = ' Maybe just a touch of the hand';
     sentence.appendChild(document.createTextNode(text1 + text2));
     nodeStore.setDomNode(sentence, id);
-    chrome.readingMode.getCurrentTextStartIndex = () => text1.length;
-    chrome.readingMode.getCurrentTextEndIndex = () =>
-        text1.length + text2.length;
+    const segments = [{
+      node: new AxReadAloudNode(id),
+      start: text1.length,
+      length: text1.length + text2.length,
+    }];
+    readAloudModel.setCurrentTextSegments(segments);
 
     highlighter.highlightCurrentGranularity(
-        [id], /*scrollIntoView=*/ false,
+        segments,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
-    highlighter.removeCurrentHighlight();
+    highlighter.removeCurrentHighlight(segments);
 
     assertFalse(highlighter.hasCurrentHighlights());
     assertHtmlContains(previousReadHighlightClass, id);
@@ -311,12 +422,16 @@ suite('Highlighter', () => {
     const text2 = ' Maybe just a touch of the hand';
     sentence.appendChild(document.createTextNode(text1 + text2));
     nodeStore.setDomNode(sentence, id);
-    chrome.readingMode.getCurrentTextStartIndex = () => text1.length;
-    chrome.readingMode.getCurrentTextEndIndex = () =>
-        text1.length + text2.length;
+    const segments = [{
+      node: new AxReadAloudNode(id),
+      start: text1.length,
+      length: text1.length + text2.length,
+    }];
+    readAloudModel.setCurrentTextSegments(segments);
 
     highlighter.highlightCurrentGranularity(
-        [id], /*scrollIntoView=*/ false,
+        segments,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
     highlighter.resetPreviousHighlight();
 
@@ -334,12 +449,16 @@ suite('Highlighter', () => {
     const text2 = ' Maybe just a touch of the hand';
     sentence.appendChild(document.createTextNode(text1 + text2));
     nodeStore.setDomNode(sentence, id);
-    chrome.readingMode.getCurrentTextStartIndex = () => text1.length;
-    chrome.readingMode.getCurrentTextEndIndex = () =>
-        text1.length + text2.length;
+    const segments = [{
+      node: new AxReadAloudNode(id),
+      start: text1.length,
+      length: text1.length + text2.length,
+    }];
+    readAloudModel.setCurrentTextSegments(segments);
 
     highlighter.highlightCurrentGranularity(
-        [id], /*scrollIntoView=*/ false,
+        segments,
+        /*scrollIntoView=*/ false,
         /*shouldUpdateSentenceHighlight=*/ true);
     highlighter.clearHighlightFormatting();
 
